bot_token_subprotocols

Function bot_token_subprotocols 

pub fn bot_token_subprotocols(token: &str) -> Vec<String>
Build the Sec-WebSocket-Protocol offer that carries the bot token: [sentinel, token]. The sentinel marks “the next value is my bot token”; the api gateway extracts the token from this header (so it never appears in any access log / URL) and echoes the sentinel back on accept.